<div align="center">

<img src="https://socialify.git.ci/Sitoi/dailycheckin/image?font=Rokkitt&forks=1&issues=1&language=1&name=1&owner=1&pattern=Circuit%20Board&pulls=1&stargazers=1&theme=Dark">

<h1>DailyCheckIn</h1>

基于「Docker」/「青龙面板」/「群晖」/「本地」的每日签到脚本

<!-- SHIELD GROUP -->

[![][github-releases-shield]][github-releases-link]
[![][pypi-version-shield]][pypi-version-link]
[![][github-release-date-shield]][github-release-date-link]
[![][github-stars-shield]][github-stars-link]
[![][github-forks-shield]][github-forks-link]
[![][github-issues-shield]][github-issues-link]
[![][github-contributors-shield]][github-contributors-link]

[![][docker-pull-shield]][docker-pull-link]
[![][docker-size-shield]][docker-size-link]
[![][docker-stars-shield]][docker-stars-link]
[![][pypi-dm-shield]][pypi-dm-link]
[![][github-license-shield]][github-license-link]

</div>

## 📢 声明

- 本仓库发布的脚本及其中涉及的任何解锁和解密分析脚本，仅用于测试和学习研究，禁止用于商业用途，不能保证其合法性，准确性，完整性和有效性，请根据情况自行判断。

- 本项目内所有资源文件，禁止任何公众号、自媒体进行任何形式的转载、发布。

- 本人对任何脚本问题概不负责，包括但不限于由任何脚本错误导致的任何损失或损害。

- 间接使用脚本的任何用户，包括但不限于建立 VPS 或在某些行为违反国家/地区法律或相关法规的情况下进行传播, 本人对于由此引起的任何隐私泄漏或其他后果概不负责。

- 请勿将本仓库的任何内容用于商业或非法目的，否则后果自负。

- 如果任何单位或个人认为该项目的脚本可能涉嫌侵犯其权利，则应及时通知并提供身份证明，所有权证明，我们将在收到认证文件后删除相关脚本。

- 任何以任何方式查看此项目的人或直接或间接使用该项目的任何脚本的使用者都应仔细阅读此声明。本人保留随时更改或补充此免责声明的权利。一旦使用并复制了任何相关脚本或 Script 项目的规则，则视为您已接受此免责声明。

**您必须在下载后的 24 小时内从计算机或手机中完全删除以上内容**

> **_您使用或者复制了本仓库且本人制作的任何脚本，则视为 `已接受` 此声明，请仔细阅读_**

## ✨ 特性

- 📦 支持 Pypi 包安装
- 💻 支持多个平台部署
- ⚙️ 支持多个平台签到
- 📢 支持多个平台通知
- ♾️ 支持多个账号签到
- 🕙 支持定时任务设置
- 🆙 支持项目自动更新

## 🦄 教程

[https://sitoi.github.io/dailycheckin/](https://sitoi.github.io/dailycheckin/)

## 🤝 参与贡献

我们非常欢迎各种形式的贡献。如果你对贡献代码感兴趣，可以查看我们的 GitHub [Issues][github-issues-link]，大展身手，向我们展示你的奇思妙想。

[![][pr-welcome-shield]][pr-welcome-link]

### 💗 感谢我们的贡献者

[![][github-contrib-shield]][github-contrib-link]

## ✨ Star 数

[![][starchart-shield]][starchart-link]

---

## 📝 License

This project is [MIT](./LICENSE) licensed.

<!-- LINK GROUP -->

[github-codespace-link]: https://codespaces.new/sitoi/dailycheckin
[github-codespace-shield]: https://github.com/sitoi/dailycheckin/blob/main/images/codespaces.png?raw=true
[github-contributors-link]: https://github.com/sitoi/dailycheckin/graphs/contributors
[github-contributors-shield]: https://img.shields.io/github/contributors/sitoi/dailycheckin?color=c4f042&labelColor=black&style=flat-square
[github-forks-link]: https://github.com/sitoi/dailycheckin/network/members
[github-forks-shield]: https://img.shields.io/github/forks/sitoi/dailycheckin?color=8ae8ff&labelColor=black&style=flat-square
[github-issues-link]: https://github.com/sitoi/dailycheckin/issues
[github-issues-shield]: https://img.shields.io/github/issues/sitoi/dailycheckin?color=ff80eb&labelColor=black&style=flat-square
[github-license-link]: https://github.com/sitoi/dailycheckin/blob/main/LICENSE
[github-license-shield]: https://img.shields.io/github/license/sitoi/dailycheckin?labelColor=black&style=flat-square
[github-stars-link]: https://github.com/sitoi/dailycheckin/stargazers
[github-stars-shield]: https://img.shields.io/github/stars/sitoi/dailycheckin?color=ffcb47&labelColor=black&style=flat-square
[github-releases-link]: https://github.com/sitoi/dailycheckin/releases
[github-releases-shield]: https://img.shields.io/github/v/release/sitoi/dailycheckin?labelColor=black&style=flat-square
[github-release-date-link]: https://github.com/sitoi/dailycheckin/releases
[github-release-date-shield]: https://img.shields.io/github/release-date/sitoi/dailycheckin?labelColor=black&style=flat-square
[pr-welcome-link]: https://github.com/sitoi/dailycheckin/pulls
[pr-welcome-shield]: https://img.shields.io/badge/🤯_pr_welcome-%E2%86%92-ffcb47?labelColor=black&style=for-the-badge
[github-contrib-link]: https://github.com/sitoi/dailycheckin/graphs/contributors
[github-contrib-shield]: https://contrib.rocks/image?repo=sitoi%2Fdailycheckin
[docker-pull-shield]: https://img.shields.io/docker/pulls/sitoi/dailycheckin?labelColor=black&style=flat-square
[docker-pull-link]: https://hub.docker.com/repository/docker/sitoi/dailycheckin
[docker-size-shield]: https://img.shields.io/docker/image-size/sitoi/dailycheckin?labelColor=black&style=flat-square
[docker-size-link]: https://hub.docker.com/repository/docker/sitoi/dailycheckin
[docker-stars-shield]: https://img.shields.io/docker/stars/sitoi/dailycheckin?labelColor=black&style=flat-square
[docker-stars-link]: https://hub.docker.com/repository/docker/sitoi/dailycheckin
[pypi-dm-shield]: https://img.shields.io/pypi/dm/dailycheckin?label=pypi&labelColor=black&style=flat-square
[pypi-dm-link]: https://pypi.org/project/dailycheckin/
[pypi-version-shield]: https://img.shields.io/pypi/v/dailycheckin?labelColor=black&style=flat-square
[pypi-version-link]: https://pypi.org/project/dailycheckin/
[starchart-shield]: https://starchart.cc/Sitoi/dailycheckin.svg
[starchart-link]: https://starchart.cc/Sitoi/dailycheckin
